@@ -20,7 +20,7 @@ ggs_histogram <- function(D, family=NA, bins=30) {
   l <- unlist(dlply(D, .(Parameter), here(summarize), calc.bin(value, bins)), recursive=FALSE)
   dl <- dim(l[[1]]) # only the dimensions of the first parameter are needed to recreate Parameter names
   ds <- rbind.fill(l)
-  ds <- cbind(Parameter=gl(attributes(D)$nParameter, dl[1], labels=levels(D$Parameter)), ds)
+  ds <- cbind(Parameter=gl(attributes(D)$nParameters, dl[1], labels=levels(D$Parameter)), ds)
   # Plot
   f <- ggplot(ds, aes(x=x, y=count, width=width)) + geom_bar(stat="identity", position="identity") +
     facet_wrap(~ Parameter, ncol=1, scales="free")
