@@ -8,8 +8,13 @@ if (base::getRversion() >= "2.15.1") {
     "Lag", "Autocorrelation", # from ggs_autocorrelation
     "thick.low", "thick.high", "thin.low", "thin.high", # from ggs_caterpillar
     "part_chain", # for ggs_compare_partial
-    "X1", "X2", # for ggs_crosscorrelation
+    "Var1", "Var2", # for ggs_crosscorrelation
     "n", "z", "part", # for ggs_geweke
-    "m" # for ggs_geweke and ggs_running
+    "sd", # for ggs_ppsd
+    "x", "width", # for ggs_histogram
+    "Posterior predictive mean", "Posterior predictive standard deviation", # for ggs_ppmean and ggs_ppsd
+    "Specificity", "Sensitivity", # for ggs_rocplot()
+    "low", "high", "y", # for ggs_separation()
+    "m" # for ggs_geweke, ggs_running, ggs_ppmean
   ))
 }
